```yaml
---
title: "Protocolo de Investigación: Uso de Markdown para la Redacción Científica"
author: Gerardo Marx Chávez-Campos
bibliography: referencias.bib
csl: ieee.csl
header-includes:
  - \usepackage{graphicx}
  - \usepackage{booktabs}
  - \usepackage{amsmath}
output: pdf
---
```

## Introducción

La redacción científica es una competencia fundamental para investigadores y estudiantes de posgrado [@lopez2021tesis] . En la era digital, el uso de lenguajes de marcado como Markdown ha cobrado relevancia por su simplicidad [@garcia2023markdown], compatibilidad y capacidad de conversión a múltiples formatos mediante herramientas como Pandoc [@witting2019],[@pandoc_manual].


## Antecedentes

Diversos autores han explorado metodologías para facilitar la escritura académica con tecnologías abiertas. Por ejemplo, Nobis et al. (2022) discuten el uso de Markdown y Pandoc como herramientas efectivas para la producción científica reproducible [@nobis2022markdown]. Además, herramientas como Zettlr y Obsidian han sido adoptadas en contextos educativos para gestionar bibliografía y redactar textos con apoyo de BibTeX [@knuth1984texbook].

## Objetivo General

Explorar y ejemplificar el uso de Markdown y Pandoc como herramientas para la redacción estructurada de protocolos y artículos de investigación científica.

## Objetivos Específicos

- Redactar un protocolo completo en formato Markdown.
- Integrar referencias bibliográficas con BibTeX.
- Usar Pandoc para convertir el archivo a PDF, DOCX y otros formatos.
- Emplear plantillas de Word para estandarizar la salida.

## Metodología

### Herramientas

- Markdown (.md) como formato base.
- BibTeX (.bib) para gestión bibliográfica.
- Pandoc para conversión de formatos.
- Plantilla de Word para formato estándar de salida.

### Estructura del archivo Markdown

El archivo incluirá metadatos (YAML) al inicio del archivo `md` que debe tener una estructura similar a la siguiente:

```yaml
---
title: "Protocolo de Investigación"
author: "Tu Nombre"
date: \today
fontsize: 12pt
geometry: margin=2.5cm
documentclass: article
header-includes:
  - \usepackage{graphicx}
  - \usepackage{amsmath}
  - \usepackage{hyperref}
  - \usepackage{float}
  - \usepackage{booktabs}
  - \usepackage[spanish]{babel}
  - \usepackage[utf8]{inputenc}
  - \usepackage[T1]{fontenc}
  - \usepackage{lipsum}
---
```

Después de los metadatos, el contenido del  archivo está estructurado en función de la convocatoria, formato de publicación o plantilla. Las citas bibliográficas se realizarán siguiendo la siguiente sintaxis `[@clave]`. Estas claves de cita son definidas en un archivo complementario, que en el caso de este repositorio es llamado `referencias.bib`. 

### Archivos bibtex

El contenido del archivo `referencias.bib` sigue el formato tipo Bibtex y a continuación se indican las estructuras de las entradas más comunes como: artículos, libros, capítulos de libro, tesis, congresos, recursos en la web.

**Artículo de revista**
```bibtex
@article{apellido2024ejemplo,
  author  = {Apellido, Nombre},
  title   = {Título del artículo},
  journal = {Nombre de la Revista},
  year    = {2024},
  volume  = {12},
  number  = {3},
  pages   = {123--134},
  doi     = {10.1234/ejemplo.doi}
}
```

**Libro**
```bibtex
@book{autor2022libro,
  author    = {Apellido, Nombre},
  title     = {Título del Libro},
  publisher = {Editorial Ejemplo},
  year      = {2022},
  edition   = {2},
  address   = {Ciudad}
}
```

**Capítulo de libro**
```bibtex
@incollection{apellido2021capitulo,
  author    = {Apellido, Nombre},
  title     = {Título del Capítulo},
  booktitle = {Título del Libro},
  editor    = {Editor, Nombre},
  publisher = {Editorial},
  year      = {2021},
  pages     = {45--60},
  address   = {Ciudad}
}
```

**Trabajo de tesis**
```bibtex
@phdthesis{gomez2020tesis,
  author = {Gómez, Carla},
  title  = {Título de la Tesis},
  school = {Nombre de la Universidad},
  year   = {2020},
  type   = {Tesis Doctoral}
}
```

**Trabajo de congreso**
```bibtex
@inproceedings{rojas2023congreso,
  author    = {Rojas, Pedro},
  title     = {Título del Trabajo},
  booktitle = {Memorias del Congreso Internacional de Ingeniería},
  year      = {2023},
  pages     = {234--240},
  address   = {Ciudad, País}
}
```

**Recursos web**
```bibtex
@misc{pandocmanual,
  author = {MacFarlane, John},
  title  = {Pandoc User's Guide},
  year   = {2024},
  note   = {Disponible en: \\url{https://pandoc.org/MANUAL.html}}
}
```

### Estilos de citas CSL

https://github.com/citation-style-language/styles-distribution/blob/master/ieee.csl?


### Ejemplos de comandos Pandoc

```bash
# Convertir a PDF usando cita bibliográfica y plantilla de CSL
pandoc protocolo.md --citeproc -o protocolo.pdf

# Convertir a DOCX con plantilla personalizada
pandoc protocolo.md --citeproc --reference-doc=plantilla.docx -o protocolo.docx

# Convertir a HTML
pandoc protocolo.md --citeproc -o protocolo.html
```

### Flujo de trabajo

1. Crear archivo `protocolo.md`.
2. Crear archivo `referencias.bib`.
3. Ejecutar comandos Pandoc desde terminal.
4. Validar formato de salida.

## Referencias

Las referencias se encuentran almacenadas en el archivo `referencias.bib` y se integran automáticamente mediante Pandoc.
